C_____INTEGRATIONSVERSION___:_s_8714
C
C * * *
C
C  BERECHNUNG VON 2D-SPLINEFUNKTIONEN
C  DATENORGANISATION, BERECHNUNG DES RESIDUUMS ETC.
C
C * * *
C
C  AUTOR :       M. ARNOLD , U ROSTOCK
C  VERSION VOM : 11. MAI 1994
C
C * * *
C
C  STEUERDATEN EINLESEN
C
C  PARAMETER
C    SDEG   (OUTPUT) : GRAD DER SPLINEFUNKTION
C    NDAT   (OUTPUT) : ANZAHL DER APPROXIMATIONSPROBLEME
C    IROT   (OUTPUT) : STEUERPARAMETER DREHUNG KOORDINATENSYSTEM
C                        0  ...  DREHPARAMETER BERECHNEN
C                        1  ...  DREHPARAMETER VORGEGEBEN
C    AROT   (OUTPUT) : DREHPARAMETER KOORDINATENSYSTEM
C    X1JUMP (OUTPUT) : NAEHERUNG FUER KONTAKTPUNKTSPRUNG IN X1
C    SJUMP  (OUTPUT) : LAGE DES KONTAKTPUNKTSPRUNGS RAD    IN M
C    NBAS1  (OUTPUT) : ANZAHL DER GITTERPUNKTE X1-RICHTUNG
C                      BASISGITTER (AEQUIDISTANT)
C    NADD1  (OUTPUT) : ANZAHL DER GITTERPUNKTE X1-RICHTUNG
C                      ZUSAETZLICHE GITTERPUNKTE AM FLANKENANLAUF
C    NBAS2  (OUTPUT) : ANZAHL DER GITTERPUNKTE X2-RICHTUNG
C    YMIN   (OUTPUT) : MINIMALE SEITENVERSCHIEBUNG  Y      IN M
C    YMAX   (OUTPUT) : MAXIMALE SEITENVERSCHIEBUNG  Y      IN M
C    DELY   (OUTPUT) : INKREMENT SEITENVERSCHIEBUNG  Y     IN M
C                      DEFINIERT GITTER FUER APPROXIMATION
C    RESY   (OUTPUT) : INKREMENT SEITENVERSCHIEBUNG  Y     IN M
C                      DEFINIERT GITTER FUER RESIDUENBERECHNUNG
C    PHIMIN (OUTPUT) : MINIMALER ROLLWINKEL  PHI           IN DEG
C    PHIMAX (OUTPUT) : MAXIMALER ROLLWINKEL  PHI           IN DEG
C    DELPHI (OUTPUT) : INKREMENT ROLLWINKEL  PHI           IN DEG
C                      DEFINIERT GITTER FUER APPROXIMATION
C    RESPHI (OUTPUT) : INKREMENT ROLLWINKEL  PHI           IN DEG
C                      DEFINIERT GITTER FUER RESIDUENBERECHNUNG
C    IDAT   (OUTPUT) : SPALTENINDEX IN COEFF
C    ITASK  (OUTPUT) : MARKIERUNG IN DER AUSGABEDATEI
C    RPAR   (-)      : USER DEFINED ARRAY (REAL)
C    IPAR   (-)      : USER DEFINED ARRAY (INTEGER)
C
C
C  USER DEFINED ARRAYS:
C
C  IPAR
C     1  : FLAG FOR TYPE OF APPROXIMATION PROBLEM
C          = 1  ...  CONSTRAINT PARAMETERS:           S, D                     ( NDAT = 2  )
C=H.N      = 2  ...  PARAMETERS FOR FRICTION FORCES:  S  , V  , AB , RHO , CK  ( NDAT = 13 )
C                                                     PEN, C11, C22, C23
C                                                     Cxx, Cxz, Cyy, Cyz
C  RPAR
C     1  : RADIUS OF WHEEL R0                       IN M
C     2  : LATERAL DISPLACEMENT Y                   IN M
C     3  : ROLL ANGLE PHI                           IN DEG
C     4  : YAW ANGLE  PSI                           IN DEG
C     5  : VALUE  D  OF DISTANCE FUNCTION           IN M
C     6  : CONTACT POINT  V  RAIL                   IN M
C     8  : POISSON-NUMBER SIGMA
C    10  : MIN. POSITION OF CONTACT POINT WHEEL     IN M
C    11  : MAX. POSITION OF CONTACT POINT WHEEL     IN M
C    12  : INCREMENT CONTACT POINT WHEEL            IN M
C    13  : ERROR BOUND (ABSOLUTE)
C    14  : ERROR BOUND (RELATIVE)
C    20  : WEIGHT IF CONTACT ON FLANGE
C
C
      SUBROUTINE DATORG ( SDEG, NDAT, IROT, AROT, X1JUMP, SJUMP,
     *                    NBAS1, NADD1, NBAS2, YMIN, YMAX, DELY, RESY,
     *                    PHIMIN, PHIMAX, DELPHI, RESPHI, IDAT, ITASK,
     *                    RPAR, IPAR )
C
      USE m_paramet_char     ! define simpack/3d global string-lengths
      IMPLICIT NONE
C
      INTEGER           IDAT(*), ITASK(*)
C
      DOUBLE PRECISION  AROT, X1JUMP, SJUMP, YMIN, YMAX, DELY, RESY,
     *                  PHIMIN, PHIMAX, DELPHI, RESPHI
      INTEGER           SDEG, NDAT, IROT, NBAS1, NADD1, NBAS2
C
      DOUBLE PRECISION  RPAR(*)
      INTEGER           IPAR(*)
C
      INTEGER           IDAT1(2), ITASK1(2), IDAT2(13), ITASK2(13)
C
      DOUBLE PRECISION  R0, PSIDEG, GMOD, SIGMA, SMIN, SMAX, DELS,
     *                  ATOL, RTOL, WFL
      INTEGER           I, J
C
      DATA       IDAT1   / 2, 1 /
      DATA       ITASK1  / 3, 4 /
C
      DATA
     +  IDAT2   / 1, 2, 3, 4, 5, 6 , 7 , 8 , 9 , 10, 11, 12, 13 /
      DATA
     +  ITASK2  / 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17 /
C
C
      RPAR( 4) =    3.          ! PSIDEG
      RPAR(10) =   -0.5         ! SMIN
      RPAR(11) =    0.5         ! SMAX
cc      RPAR(10) =   -0.06        ! SMIN
cc      RPAR(11) =    0.06        ! SMAX
      RPAR(12) =    0.005       ! SMIN
      RPAR(13) =    1.d-08      ! ATOL
      RPAR(14) =    1.d-08      ! RTOL
C
      IROT     =    1
      AROT     =    0.
      X1JUMP   =    0.
      RPAR(20) =    1.          ! WFL
      RPAR(22) =  -100.         ! SJUMP
      NADD1    =    0
      NBAS1    =   10
      NBAS2    =    5
C
      IF ( IPAR(1) .EQ. 1 ) THEN
         NDAT = 2
         DO 10 I=1,NDAT
            IDAT(I)  = IDAT1(I)
            ITASK(I) = ITASK1(I)
   10    CONTINUE
         SDEG = 4
      ELSE
        NDAT = 13
        DO 20 I=1,NDAT
          IDAT(I)  = IDAT2(I)
          ITASK(I) = ITASK2(I)
   20     CONTINUE
          SDEG = 2
      ENDIF
C
      RETURN
      END


