C =====================================================================
C INCLUDE-BLOCK: VBEO98   =============================================
C =====================================================================
C
C state    | editor                | comment
C ---------+-----------------------+--------------
C xx-xx-xx | W.Rulka               | author
C 98-09-05 | G.Schupp              | s-variable rail profiles / switch via interface and general corrections
C 99-04-25 | K.Schroeder,G.Schupp  | Use of an arbitrary number of Wheelset-types: Dynamically allocated arrays
C          |                       | for wheel/rail profiles/tables are used; these are based of FORTRAN90
C 01-02-13 | W.Rulka               | global wheelset-counter added "isumbeo_global_counter"
C 01-02-07 | K.Schroeder           | . introduced rb88_store for transfer/storage of information for wheel-on-roller
C 02-03-19 | W.Trautenberg         | increased n_wheelset_max from 25 to 100
C 04-01-23 | W.Trautenberg         | increased n_wheelset_max from 100 to 150
C 07-04-02 | C.Weidemann           | increased n_wheelset_max from 150 to 1000
C ...      | ...                   | ...
C
C --------
C Purpose: Declarations for: Wheel-Rail applications
C -------- - arrays sorted by the wheelset-id: nbeo
C                      - for marker-type 98: - moving along the track
C                                            - profile reference frames
C                      - for track-joint's
C
C ---------------------------------------------------------------------
C
C     -----------------
C     Max-Declarations
C     -----------------
      INTEGER        n_wheelset_max
      PARAMETER(     n_wheelset_max = 1000 )      ! maximum number of "wheelsets" (markers for describing the postions on a track)
      INTEGER        n_wheelset_info_max
      PARAMETER(     n_wheelset_info_max = 40 )   ! maximum number of info's per wheelset
C
C     ------------------------------------------
C     Info's about defined joints, markers, ...
C     ------------------------------------------
      INTEGER n_wheelsets                       ! number of defined wheelsets (usually set by bebib.f)
C
      INTEGER ke_wheelset( n_wheelset_info_max  ! ke_wheelset(L,nbeo): Storing global info's
     +                   , n_wheelset_max)      !   Storing global info's (usually - defaults by pevorb.f
                                                !                                - set by: -pebe97.f
                                                !                         )
                                                !   with the wheeset-id stored in wheel-rail markers, forces, constraints
                                                !   it will be very easy to set up preprocessings using "ke_wheelset"-array
                                                !
                                                !   L=1 : track-joint id        ............................ set by pege07.f
                                                !   L=2 : rail-contact body right  ......................... set by pebe97.f
                                                !   L=3 : rail-contact body left   ......................... set by pebe97.f
                                                !   L=4 : rail-marker for profile reference frame right..... set by pebe97.f
                                                !   L=5 : rail-marker for profile reference frame left ..... set by pebe97.f
                                                !   L=6 : rail-marker for parent contact 1 right ........... set by pebe97.f
                                                !   L=7 : rail-marker for parent contact 1 left  ........... set by pebe97.f
                                                !   L=8 : rail-marker for child  contact 2 right ........... set by pebe97.f
                                                !   L=9 : rail-marker for child  contact 2 left  ........... set by pebe97.f
                                                !   L=10: rail-marker for child  contact 3 right ........... set by pebe97.f
                                                !   L=11: rail-marker for child  contact 3 left  ........... set by pebe97.f
                                                !   L=12: wheel-contact body right     --------- already not set -----------
                                                !   L=13: wheel-contact body left      --------- already not set -----------
                                                !   L=14: wheel-marker for profile reference frame right ... set by pebe97.f
                                                !   L=15: wheel-marker for profile reference frame left .... set by pebe97.f
                                                !   L=16: wheel-marker for parent contact right   .......... set by pebe97.f
                                                !   L=17: wheel-marker for parent contact left   ........... set by pebe97.f
                                                !   L=18: wheel-marker for child  contact 2 right .......... set by pebe97.f
                                                !   L=19: wheel-marker for child  contact 2 left ........... set by pebe97.f
                                                !   L=20: wheel-marker for child  contact 3 right .......... set by pebe97.f
                                                !   L=21: wheel-marker for child  contact 3 left ........... set by pebe97.f
                                                !   L=25: friction force 1 right   ......................... set by pebe97.f
                                                !   L=26: friction force 1 left   .......................... set by pebe97.f
                                                !   L=27: friction force 2 right ........................... set by pebe97.f
                                                !   L=28: friction force 2 left  ........................... set by pebe97.f
                                                !   L=29: friction force 3 right ........................... set by pebe97.f
                                                !   L=30: friction force 3 left  ........................... set by pebe97.f
                                                !   L=31: id of wheelset-type............................... set by pege07.f

      INTEGER ke_wheelsetb( n_wheelset_info_max ! ke_wheelsetb(L,nbeo): Storing global info's
     +                    , n_wheelset_max)     !   Storing global info's for Wheel Back Contact(usually - defaults by pevorb.f

                                                !   with the wheeset-id stored in wheel-rail markers, forces, constraints
                                                !   it will be very easy to set up preprocessings using "ke_wheelset"-array
                                                !
                                                !   L=1 : track-joint id        ............................ set by pege07.f
                                                !   L=2 : rail-contact body right  ......................... set by pebe97.f
                                                !   L=3 : rail-contact body left   ......................... set by pebe97.f
                                                !   L=4 : rail-marker for profile reference frame right..... set by pebe97.f
                                                !   L=5 : rail-marker for profile reference frame left ..... set by pebe97.f
                                                !   L=6 : rail-marker for parent contact 1 right ........... set by pebe97.f
                                                !   L=7 : rail-marker for parent contact 1 left  ........... set by pebe97.f
                                                !   not needed->not set L=8 : rail-marker for child  contact 2 right ........... set by pebe97.f
                                                !   not needed->not set L=9 : rail-marker for child  contact 2 left  ........... set by pebe97.f
                                                !   not needed->not set L=10: rail-marker for child  contact 3 right ........... set by pebe97.f
                                                !   not needed->not set L=11: rail-marker for child  contact 3 left  ........... set by pebe97.f
                                                !   L=12: wheel-contact body right     --------- already not set -----------
                                                !   L=13: wheel-contact body left      --------- already not set -----------
                                                !   L=14: wheel-marker for profile reference frame right ... set by pebe97.f
                                                !   L=15: wheel-marker for profile reference frame left .... set by pebe97.f
                                                !   L=16: wheel-marker for parent contact right   .......... set by pebe97.f
                                                !   L=17: wheel-marker for parent contact left   ........... set by pebe97.f
                                                !   not needed->not set L=18: wheel-marker for child  contact 2 right .......... set by pebe97.f
                                                !   not needed->not set L=19: wheel-marker for child  contact 2 left ........... set by pebe97.f
                                                !   not needed->not set L=20: wheel-marker for child  contact 3 right .......... set by pebe97.f
                                                !   not needed->not set L=21: wheel-marker for child  contact 3 left ........... set by pebe97.f
                                                !   L=25: friction force 1 right   ......................... set by pebe97.f
                                                !   L=26: friction force 1 left   .......................... set by pebe97.f
                                                !   not needed->not set L=27: friction force 2 right ........................... set by pebe97.f
                                                !   not needed->not set L=28: friction force 2 left  ........................... set by pebe97.f
                                                !   not needed->not set L=29: friction force 3 right ........................... set by pebe97.f
                                                !   not needed->not set L=30: friction force 3 left  ........................... set by pebe97.f
                                                !   L=31: id of wheelset-type............................... set by pege07.f

      CHARACTER*(30) c_wstype( n_wheelset_max ) !  Wheelset-type (stored as character-string): Every wheelset-type is stored here just ONCE!!!
C
C     -----------------------------------------------------------------------------------------------
C     Global arrays passing informations from reprocessor
C     pebe97.f and global calculation module ubeo97.f
C     to MBS-element programs: ubeo97, ufelxx, ...
C     ----------------------------------------------------------------------------------------------

C     1) General
C        -------
C        Tread & Flange
C        --------------
         INTEGER        i_s98, i_ss98
     *                , ib98_err(n_wheelset_max)            ! error-flag for wheelsets:
                                                            ! =0: contact points are calculated
                                                            ! =1: no contact point found
C        Back of Wheel
C        -------------
         INTEGER        ib98b_err(n_wheelset_max)           ! error-flag for wheelsets
                                                            ! =0: contact points are calculated
                                                            ! =1: no contact point found
C        Tread & Flange
C        --------------
         DOUBLE PRECISION
     *                  rb98(26,n_wheelset_max)           ! r_x, r_y, r_z, phi, gamma, psi: Rosition and orientation of the marker
     *                , rb98_fz_n(16,n_wheelset_max)      ! storing gradients of quick wheelsets for nominal force calculations
     *                , rb98_fz_z(4,n_wheelset_max)       ! storing constraints / Hessian w.r.t. psi
*                             ! (i.e. dependent coordinates of joint type 08)
     *                , rb98_cont( 6,n_wheelset_max)      ! contact coordinates right passed from ubeo97.f to friction-forces
*                             !     (ufel88/89.f and plotted as afel)
     *                , rb98_contl(6,n_wheelset_max)      ! contact coordinates left  passed from ubeo97.f to friction-forces
*                             !     (ufel88/89.f and plotted as afel)
     *                , rb98_contv( 6,n_wheelset_max)     ! contact coordinates in x right passed from ubeo97.f to friction-forces
*                             !     (ufel88/89.f and plotted as afel)
     *                , rb98_contvl(6,n_wheelset_max)     ! contact coordinates in x left  passed from ubeo97.f to friction-forces
*                             !     (ufel88/89.f and plotted as afel)
     *                , rb97_contwr(3,n_wheelset_max)     ! Position right: excited Track frame
                                                          !      --> Contact frame on wheel w.r.t. Track frame
     *                , tb97_contwr(3,n_wheelset_max)     ! Contact normal wheel right w.r.t. Track fram
                                                          ! (Last column of orientation matrix: excited Track frame
                                                          !      --> Contact frame on wheel)
     *                , rb97_contwl(3,n_wheelset_max)     ! Position left: excited Track frame
                                                          !      --> Contact frame on wheel w.r.t. Track frame
     *                , tb97_contwl(3,n_wheelset_max)     ! Contact normal wheel left w.r.t. Track fram
                                                          ! (Last column of orientation matrix: excited Track frame
                                                          ! --> Contact frame on wheel)
     *                , tb98_steq(n_wheelset_max)         ! Total rot. from track frame to wheelset frame (for static equilibrium)
     *                , rb97_wheell(3,n_wheelset_max)     ! for wheel left:  i=1: vorverlagerung
                                                          !          i=2: contact coordinate s
                                                          !          i=3: distance z
     *                , rb97_wheelr(3,n_wheelset_max)     ! for wheel right: i=1: vorverlagerung
                                                          !          i=2: contact coordinate s
                                                          !          i=3: distance z
         DOUBLE PRECISION, TARGET:: rb88_store(32, 2, n_wheelset_max)! left/right intermediate results needed for acceleration of roller-profref (see ubeor88_99)


C        Back of Wheel
C        -------------
         DOUBLE PRECISION
     *                  rb98b(26,n_wheelset_max)          ! r_x, r_y, r_z, phi, gamma, psi: Rosition and orientation of the marker

     *                , rb98b_cont( 6,n_wheelset_max)     ! contact coordinates right passed from ubeo97.f to friction-forces
                                                          !         (ufel88/89.f and plotted as afel)
     *                , rb98b_contl(6,n_wheelset_max)     ! contact coordinates left  passed from ubeo97.f to friction-forces
                                                          !         (ufel88/89.f and plotted as afel)
     *                , rb98b_contv( 6,n_wheelset_max)    ! contact coordinates in x right passed from ubeo97.f to friction-forces
                                                          !         (ufel88/89.f and plotted as afel)
     *                , rb98b_contvl(6,n_wheelset_max)    ! contact coordinates in x left  passed from ubeo97.f to friction-forces
                                                          !         (ufel88/89.f and plotted as afel)
c
     *                , rb98b_ex( 3,n_wheelset_max)       ! Position    Inertial --> excited Track frame
     *                , tb98b_ex( 3,3,n_wheelset_max)     ! Orientation Inertial --> excited Track frame
c
     *                , tb98b_steq(n_wheelset_max)        ! Total rot. from track frame to wheelset frame (for static equilibrium)
     *                , rb97b_wheell(3,n_wheelset_max)    ! for wheel left:  i=1: vorverlagerung
                                                          !          i=2: contact coordinate s
                                                          !          i=3: distance z
     *                , rb97b_wheelr(3,n_wheelset_max)    ! for wheel right: i=1: vorverlagerung
                                                          !          i=2: contact coordinate s
                                                          !          i=3: distance z
C        Tread & Flange
C        --------------
         DOUBLE PRECISION
     *                  tip98_l(3,3,n_wheelset_max)       ! orientation from inertia frame to profile reference frame of left  rail
     *                , tip98_r(3,3,n_wheelset_max)       ! orientation from inertia frame to profile reference frame of right rail
     *                , tic98_l(3,3,n_wheelset_max)       ! orientation from inertia frame to contact reference frame of left  rail
     *                , tic98_r(3,3,n_wheelset_max)       ! orientation from inertia frame to contact reference frame of right rail
     *                , ttp98_l(3,3,n_wheelset_max)       ! orientation from track   frame to profile reference frame of left  rail
     *                , ttp98_r(3,3,n_wheelset_max)       ! orientation from track   frame to profile reference frame of right rail
     *                , ttc98_l(3,3,n_wheelset_max)       ! orientation from track   frame to contact reference frame of left  rail
     *                , ttc98_r(3,3,n_wheelset_max)       ! orientation from track   frame to contact reference frame of right rail
     *                , tic98_l_tab(3,3,n_wheelset_max)   ! orientation from inertia frame to contact reference frame of left  rail
     *                , tic98_r_tab(3,3,n_wheelset_max)   ! orientation from inertia frame to contact reference frame of right rail
     *                , ttc98_l_tab(3,3,n_wheelset_max)   ! orientation from track   frame to contact reference frame of left  rail
     *                , ttc98_r_tab(3,3,n_wheelset_max)   ! orientation from track   frame to contact reference frame of right rail
     *                , tit(3,3,n_wheelset_max)           ! orientation from inertia frame to track frame

C        Back of Wheel
C        -------------
         DOUBLE PRECISION
     *     tip98b_l(3,3,n_wheelset_max)      ! orientation from inertia frame to profile reference frame of left  rail
     *   , tip98b_r(3,3,n_wheelset_max)      ! orientation from inertia frame to profile reference frame of right rail
     *   , tic98b_l(3,3,n_wheelset_max)      ! orientation from inertia frame to contact reference frame of left  rail
     *   , tic98b_r(3,3,n_wheelset_max)      ! orientation from inertia frame to contact reference frame of right rail
     *   , ttp98b_l(3,3,n_wheelset_max)      ! orientation from track   frame to profile reference frame of left  rail
     *   , ttp98b_r(3,3,n_wheelset_max)      ! orientation from track   frame to profile reference frame of right rail
     *   , ttc98b_l(3,3,n_wheelset_max)      ! orientation from track   frame to contact reference frame of left  rail
     *   , ttc98b_r(3,3,n_wheelset_max)      ! orientation from track   frame to contact reference frame of right rail
     *   , titb(3,3,n_wheelset_max)      ! orientation from inertia frame to track frame

C     2) globals for QUASI-Linearisation
C        -------------------------------
         DOUBLE PRECISION
     *     r_profr_contr_r(  3,n_wheelset_max) ! vector: profref_rail  -> contact_rail on right side  with respect to profref_rail
     *   , r_profr_contr_l(  3,n_wheelset_max) ! vector: profref_rail  -> contact_rail on left  side  with respect to profref_rail
     *   , r_profw_contw_r(  3,n_wheelset_max) ! vector: profref_wheel -> contact_wheel on right side with respect to profref_wheel
     *   , r_profw_contw_l(  3,n_wheelset_max) ! vector: profref_wheel -> contact_wheel on left  side with respect to profref_wheel
     *   , r_profr_profw_r(  3,n_wheelset_max) ! vector: profref_rail  -> profref_wheel on right side with respect to profref_rail
     *   , r_profr_profw_l(  3,n_wheelset_max) ! vector: profref_rail  -> profref_wheel on left  side with respect to profref_rail
     *   , A_profr_profw_r(3,3,n_wheelset_max) ! A-mat : profref_rail  -> profref_wheel on right side
     *   , A_profr_profw_l(3,3,n_wheelset_max) ! A-mat : profref_rail  -> profref_wheel on left side

C     2) globals for multiple contact
C        ----------------------------
C        Tread & Flange
C        --------------
         DOUBLE PRECISION
     *   tic98_l_tab_f1(3,3,n_wheelset_max)  ! orient. from inertia frame to contact reference frame of left  rail flange point 1
     * , tic98_r_tab_f1(3,3,n_wheelset_max)  ! orient. from inertia frame to contact reference frame of right rail flange point 1
     * , ttc98_l_tab_f1(3,3,n_wheelset_max)  ! orient. from track   frame to contact reference frame of left  rail flange point 1
     * , ttc98_r_tab_f1(3,3,n_wheelset_max)  ! orient. from track   frame to contact reference frame of right rail flange point 1
     * , tic98_l_tab_f2(3,3,n_wheelset_max)  ! orient. from inertia frame to contact reference frame of left  rail flange point 2
     * , tic98_r_tab_f2(3,3,n_wheelset_max)  ! orient. from inertia frame to contact reference frame of right rail flange point 2
     * , ttc98_l_tab_f2(3,3,n_wheelset_max)  ! orient. from track   frame to contact reference frame of left  rail flange point 2
     * , ttc98_r_tab_f2(3,3,n_wheelset_max)  ! orient. from track   frame to contact reference frame of right rail flange point 2

C        Back of Wheel
C        -------------
         DOUBLE PRECISION
     *   tic98b_l_f1(3,3,n_wheelset_max)     ! orient. from inertia frame to contact ref. frame of the left  rail flange point 1
     * , tic98b_r_f1(3,3,n_wheelset_max)     ! orient. from inertia frame to contact ref. frame of the right rail flange point 1
     * , ttc98b_l_f1(3,3,n_wheelset_max)     ! orient. from track   frame to contact ref. frame of the left  rail flange point 1
     * , ttc98b_r_f1(3,3,n_wheelset_max)     ! orient. from track   frame to contact ref. frame of the right rail flange point 1
     * , tic98b_l_f2(3,3,n_wheelset_max)     ! orient. from inertia frame to contact ref. frame of the left  rail flange point 2
     * , tic98b_r_f2(3,3,n_wheelset_max)     ! orient. from inertia frame to contact ref. frame of the right rail flange point 2
     * , ttc98b_l_f2(3,3,n_wheelset_max)     ! orient. from track   frame to contact ref .frame of the left  rail flange point 2
     * , ttc98b_r_f2(3,3,n_wheelset_max)     ! orient. from track   frame to contact ref. frame of the right rail flange point 2

C     3) Excitations on Track / on Rails
C        -------------------------------
         DOUBLE PRECISION
     *   rb98_excit(6,n_wheelset_max)        ! Excitation: Total difference between FIXED and EXCITED Rail Profile Reference Frame

C     4) Sleeper (calculated in ugel91 if OBRI is enabled)
C        -------
         DOUBLE PRECISION
     *   risl98 ( 3 ,n_wheelset_max)     ! Position Vector Isys -> Sleeper-BodyRefSys w.r.t. Isys
     * , trisl98(3,3,n_wheelset_max)     ! Transformation Sleeper-BodyRefSys -> Isys
C
C     ------------------------------------------
C     WheelLift Info Handling
C     ------------------------------------------
      INTEGER n_wheellift_message                           ! display wheellift message after every nn wheellift
                                                            ! detections (nn=n_wheellift_message)
c
C=KA  13.03.97, gunti: Try again with reduced stepsize if errorflag is set
c                      in user-routines (i.e. enable/react on ires = -1)
C=L      PARAMETER( n_wheellift_message = 1000 )
      PARAMETER( n_wheellift_message = 9 )                  ! SODASRT trys to reduces the stepsize ncf = 10 times
                                                            !          before termination of integration
c
C=KE  13.03.97, gunti
c
      INTEGER k_wheellift_message(n_wheelset_max)           ! counter for wheellift detections on wheelset (right+left)
      INTEGER k_wheellift_info_r (n_wheelset_max)           ! =0/1: wheellift no/yes on right side of wheellift at last call to RHS
      INTEGER k_wheellift_info_l (n_wheelset_max)           ! =0/1: wheellift no/yes on right side of wheellift at last call to RHS

C     ---------------------
C     Wheel Rail Constraint
C     ---------------------
      Double Precision      gwr_r(n_wheelset_max)
      Double Precision      gwr_l(n_wheelset_max)
      Double Precision   gjacwr_r(5, n_wheelset_max)
      Double Precision   gjacwr_l(5, n_wheelset_max)
      Double Precision  ghesswr_r(15, n_wheelset_max)
      Double Precision  ghesswr_l(15, n_wheelset_max)
      Double Precision  BLambda_r(6, 2, n_wheelset_max)
      Double Precision  BLambda_l(6, 2, n_wheelset_max)

C     ---------------------------
C     For the pebib-preprocessing (with calls to ugelxx_ini.f)
C     ---------------------------
      INTEGER           isumbeo_global_counter

C     ----------------------------------------------------------------------------------------
C     Global declaration
C     -----------------------------------------------------------------------------------------
      COMMON /sim_beo98/  rb98
     +                  , tip98_l    ,ttp98_l    ,tic98_l,ttc98_l
     +                  , tip98_r    ,ttp98_r    ,tic98_r,ttc98_r
     +                  , tic98_l_tab,tic98_r_tab, rb98_contl
     +                  , ttc98_l_tab,ttc98_r_tab, tit   ,rb98_cont
     +          , rb98_contv, rb98_contvl
     +                  , ib98_err, i_s98,i_ss98

      COMMON /sim_beo88/  rb88_store

      COMMON /sim_beo98_n/  rb98_fz_n
      COMMON /sim_beo98_z/  rb98_fz_z
      COMMON /sim_beo98_steq/ tb98_steq

      COMMON /sim_beo98_flange/
     +               tic98_l_tab_f1 , tic98_r_tab_f1
     +             , ttc98_l_tab_f1 , ttc98_r_tab_f1
     +             , tic98_l_tab_f2 , tic98_r_tab_f2
     +             , ttc98_l_tab_f2 , ttc98_r_tab_f2

      COMMON /sim_beo98_quasi/
     *               r_profr_contr_r , r_profr_contr_l
     *             , r_profw_contw_r , r_profw_contw_l
     *             , r_profr_profw_r , r_profr_profw_l
     *             , A_profr_profw_r , A_profr_profw_l

      COMMON /sim_beo98_info/
     +               n_wheelsets
     +             , ke_wheelset

      COMMON /sim_beo98_cinfo/
     +               c_wstype

      COMMON /sim_beo98_wheellift/
     +               k_wheellift_message
     +             , k_wheellift_info_r
     +             , k_wheellift_info_l

      COMMON /sim_beo97_wheel/
     +               rb97_wheell
     +             , rb97_wheelr

      COMMON /sim_beo97_constraint/
     +               gwr_r   , gwr_l
     +             , gjacwr_r, gjacwr_l
     +             , ghesswr_r, ghesswr_l
     +             , BLambda_r, BLambda_l

      COMMON /sim_beo97_contw/
     *               rb97_contwr
     *             , tb97_contwr
     *             , rb97_contwl
     *             , tb97_contwl

      COMMON /sim_beo98_back_info/
     +               ib98b_err
     +             , ke_wheelsetb

C     Back of Wheel
C     -------------
      COMMON /sim_beo98_back/
     +               rb98b
     +             , rb98b_cont  , rb98b_contl
     +             , rb98b_contv , rb98b_contvl
     +             , rb98b_ex    , tb98b_ex
     +             , tb98b_steq
     +             , rb97b_wheell, rb97b_wheelr
     +             , tip98b_l, tip98b_r
     +             , ttc98b_l, ttc98b_r
     +             , tic98b_l, tic98b_r
     +             , titb
     +             , ttp98b_l, ttp98b_r
     +             , tic98b_l_f1 , tic98b_r_f1
     +             , ttc98b_l_f1 , ttc98b_r_f1
     +             , tic98b_l_f2 , tic98b_r_f2
     +             , ttc98b_l_f2 , ttc98b_r_f2

C     Excitations
C     -----------
      COMMON /sim_beo98_excit/ rb98_excit

      COMMON /sim_beo98_sleeper/ risl98
     *                         , trisl98

C     pebib-preprocessing
C     -----------
      COMMON /sim_beo98_pebib/ isumbeo_global_counter


      SAVE  /sim_beo98_excit/  , /sim_beo98_back/      , /sim_beo98_back_info/, /sim_beo97_contw/, /sim_beo97_constraint/
     +   ,  /sim_beo97_wheel/  , /sim_beo98_wheellift/ , /sim_beo98_info /    , /sim_beo98_quasi/, /sim_beo98_flange/
     +   ,  /sim_beo98_steq/   , /sim_beo98_z /        , /sim_beo98_n /       , /sim_beo98/      , /sim_beo98_cinfo/
     +   ,  /sim_beo98_sleeper/
     +   ,  /sim_beo98_pebib/
